==> sdlskk-0.1.tar.gz: sdlskk-0.1/sdlskk.h <==
#ifndef SDLSKK_H
#define SDLSKK_H
#include <stdlib.h>

#include <SDL.h>
#include <SDL_ttf.h>


#ifdef __cplusplus
extern "C" {
#endif

typedef unsigned long SDLSKK_Char;
typedef struct SDLSKK_Dictionary SDLSKK_Dictionary;
typedef struct SDLSKK_Context SDLSKK_Context;
typedef struct SDLSKK_DictionaryItem SDLSKK_DictionaryItem;
typedef struct SDLSKK_RomKanaRuleTable SDLSKK_RomKanaRuleTable;
  

enum SDLSKK_Mode {
  SDLSKK_J_KAKUTEI_MODE,
  SDLSKK_J_HENKAN_ON_MODE,
  SDLSKK_J_HENKAN_OKURI_MODE,
  SDLSKK_J_HENKAN_ACTIVE_MODE,
  SDLSKK_LATIN_MODE,
  SDLSKK_JISX0208_LATIN_MODE,
  SDLSKK_ABBREV_MODE
};
typedef enum SDLSKK_Mode SDLSKK_Mode;
  
SDLSKK_RomKanaRuleTable* SDLSKK_RomKanaRuleTable_new( void );
void SDLSKK_RomKanaRuleTable_delete( SDLSKK_RomKanaRuleTable* rule_table );
void SDLSKK_RomKanaRuleTable_load( SDLSKK_RomKanaRuleTable* rule_table,
				   char* filename );

SDLSKK_Context* SDLSKK_Context_new( SDLSKK_Dictionary* dict,
				    SDLSKK_RomKanaRuleTable* table );
void SDLSKK_Context_delete( SDLSKK_Context* context );

void SDLSKK_Context_input_event( SDLSKK_Context* context,SDL_Event* event );

void SDLSKK_Context_input_key( SDLSKK_Context* context, char key );

char* SDLSKK_Context_get_display_str( SDLSKK_Context* context, char* cstr,
				      size_t size );
char* SDLSKK_Context_get_minibuffer_str( SDLSKK_Context* context, char* cstr,
					 size_t size );

char* SDLSKK_Context_get_str( SDLSKK_Context* context, char* cstr,
			      size_t size );
  
SDL_Surface* SDLSKK_Context_render_text( SDLSKK_Context* context,
					 TTF_Font* font,
					 SDL_Color fg );
  
SDLSKK_Dictionary* SDLSKK_Dict_new( char *filename);
int SDLSKK_Dict_load( SDLSKK_Dictionary* dict, char* filename );
void SDLSKK_Dict_delete( SDLSKK_Dictionary* dict );
void SDLSKK_Dict_delete_all( SDLSKK_Dictionary* dict );
  
#ifdef __cplusplus
}
#endif

#endif /* SDLSKK_H */

==> sdlskk-0.2.tar.gz: sdlskk-0.2/sdlskk.h <==
#ifndef SDLSKK_H
#define SDLSKK_H
#include <stdlib.h>

#include <SDL.h>
#include <SDL_ttf.h>


#ifdef __cplusplus
extern "C" {
#endif

typedef unsigned long SDLSKK_Char;
typedef struct SDLSKK_Dictionary SDLSKK_Dictionary;
typedef struct SDLSKK_Context SDLSKK_Context;
typedef struct SDLSKK_DictionaryItem SDLSKK_DictionaryItem;
typedef struct SDLSKK_RomKanaRuleTable SDLSKK_RomKanaRuleTable;
  

enum SDLSKK_Mode {
  SDLSKK_J_KAKUTEI_MODE,
  SDLSKK_J_HENKAN_ON_MODE,
  SDLSKK_J_HENKAN_OKURI_MODE,
  SDLSKK_J_HENKAN_ACTIVE_MODE,
  SDLSKK_LATIN_MODE,
  SDLSKK_JISX0208_LATIN_MODE,
  SDLSKK_ABBREV_MODE
};
typedef enum SDLSKK_Mode SDLSKK_Mode;

typedef enum SDLSKK_Error {
  SDLSKK_NOERROR = 0,
  SDLSKK_MEMERROR
} SDLSKK_Error;

typedef void (* SDLSKK_ErrorHandler)(SDLSKK_Error err);

SDLSKK_RomKanaRuleTable* SDLSKK_RomKanaRuleTable_new( char* filename );
void SDLSKK_RomKanaRuleTable_delete( SDLSKK_RomKanaRuleTable* rule_table );


SDLSKK_Context* SDLSKK_Context_new( SDLSKK_Dictionary* dict,
				    SDLSKK_RomKanaRuleTable* table );
void SDLSKK_Context_delete( SDLSKK_Context* context );

void SDLSKK_Context_input_event( SDLSKK_Context* context,SDL_Event* event );

void SDLSKK_Context_input_key( SDLSKK_Context* context, char key );

char* SDLSKK_Context_get_display_str( SDLSKK_Context* context, char* cstr,
				      size_t size );
char* SDLSKK_Context_get_minibuffer_str( SDLSKK_Context* context, char* cstr,
					 size_t size );

char* SDLSKK_Context_get_str( SDLSKK_Context* context, char* cstr,
			      size_t size );
  
SDL_Surface* SDLSKK_Context_render_display_str( SDLSKK_Context* context,
						TTF_Font* font,
						SDL_Color fg );
  
SDLSKK_Dictionary* SDLSKK_Dict_new( void );
int SDLSKK_Dict_load( SDLSKK_Dictionary* dict, char* filename, int users );
int SDLSKK_Dict_save_user_dict( SDLSKK_Dictionary* dict, char* filename );
void SDLSKK_Dict_delete( SDLSKK_Dictionary* dict );
void SDLSKK_Dict_delete_all( SDLSKK_Dictionary* dict );

void SDLSKK_set_error_func(SDLSKK_ErrorHandler handler);
  
#ifdef __cplusplus
}
#endif

#endif /* SDLSKK_H */
